# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/explore/explore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.post import post_pb2 as services_dot_post_dot_post__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/explore/explore.proto\x12\x0esocial.explore\x1a\x1cservices/common/common.proto\x1a\x18services/post/post.proto\"#\n\x10GeoSearchRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"G\n\x07\x41\x64\x64ress\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lon\x18\x04 \x01(\x01\";\n\x11GeoSearchResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.explore.Address2\xda\x01\n\x0e\x45xploreService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12\x43\n\x07GetFeed\x12\x19.social.common.Pagination\x1a\x1d.social.post.PostListResponse\x12P\n\tGeoSearch\x12 .social.explore.GeoSearchRequest\x1a!.social.explore.GeoSearchResponseb\x06proto3')



_GEOSEARCHREQUEST = DESCRIPTOR.message_types_by_name['GeoSearchRequest']
_ADDRESS = DESCRIPTOR.message_types_by_name['Address']
_GEOSEARCHRESPONSE = DESCRIPTOR.message_types_by_name['GeoSearchResponse']
GeoSearchRequest = _reflection.GeneratedProtocolMessageType('GeoSearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _GEOSEARCHREQUEST,
  '__module__' : 'services.explore.explore_pb2'
  # @@protoc_insertion_point(class_scope:social.explore.GeoSearchRequest)
  })
_sym_db.RegisterMessage(GeoSearchRequest)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'services.explore.explore_pb2'
  # @@protoc_insertion_point(class_scope:social.explore.Address)
  })
_sym_db.RegisterMessage(Address)

GeoSearchResponse = _reflection.GeneratedProtocolMessageType('GeoSearchResponse', (_message.Message,), {
  'DESCRIPTOR' : _GEOSEARCHRESPONSE,
  '__module__' : 'services.explore.explore_pb2'
  # @@protoc_insertion_point(class_scope:social.explore.GeoSearchResponse)
  })
_sym_db.RegisterMessage(GeoSearchResponse)

_EXPLORESERVICE = DESCRIPTOR.services_by_name['ExploreService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GEOSEARCHREQUEST._serialized_start=106
  _GEOSEARCHREQUEST._serialized_end=141
  _ADDRESS._serialized_start=143
  _ADDRESS._serialized_end=214
  _GEOSEARCHRESPONSE._serialized_start=216
  _GEOSEARCHRESPONSE._serialized_end=275
  _EXPLORESERVICE._serialized_start=278
  _EXPLORESERVICE._serialized_end=496
# @@protoc_insertion_point(module_scope)
