# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/hashtag/hashtag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.post import post_pb2 as services_dot_post_dot_post__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/hashtag/hashtag.proto\x12\x0esocial.hashtag\x1a\x1cservices/common/common.proto\x1a\x18services/post/post.proto\x1a\x1eservices/account/account.proto\"v\n\x07Hashtag\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\x03\x12\x11\n\tbanned_at\x18\x04 \x01(\x03\x12)\n\x04stat\x18\x05 \x01(\x0b\x32\x1b.social.hashtag.HashtagStat\"P\n\x0bHashtagStat\x12\x14\n\x0ctagged_count\x18\x01 \x01(\x03\x12\x14\n\x0cis_following\x18\x02 \x01(\x05\x12\x15\n\rcount_to_text\x18\x03 \x01(\t\"6\n\x0c\x46indResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.hashtag.Hashtag\"Y\n\x0eGetFeedRequest\x12(\n\x07hashtag\x18\x01 \x03(\x0b\x32\x17.social.hashtag.Hashtag\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"]\n\x0fGetFeedResponse\x12(\n\x07hashtag\x18\x01 \x03(\x0b\x32\x17.social.hashtag.Hashtag\x12 \n\x05items\x18\x02 \x03(\x0b\x32\x11.social.post.Post\"E\n\x1bGetHashtagFollowingResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.hashtag.Hashtag\"2\n\rToggleHashtag\x12\x12\n\nhashtag_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\x32\xc0\x04\n\x0eHashtagService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12@\n\x04\x46ind\x12\x1a.social.common.FindRequest\x1a\x1c.social.hashtag.FindResponse\x12\x37\n\x06\x46ollow\x12\x17.social.hashtag.Hashtag\x1a\x14.social.common.Empty\x12\x39\n\x08Unfollow\x12\x17.social.hashtag.Hashtag\x1a\x14.social.common.Empty\x12J\n\x07GetFeed\x12\x1e.social.hashtag.GetFeedRequest\x1a\x1f.social.hashtag.GetFeedResponse\x12\x66\n\x13GetHashtagFollowing\x12\".social.account.AccountListRequest\x1a+.social.hashtag.GetHashtagFollowingResponse\x12I\n\x12\x41\x64minHashtagDelete\x12\x1d.social.hashtag.ToggleHashtag\x1a\x14.social.common.Empty\x12\x46\n\x0f\x41\x64minHashtagBan\x12\x1d.social.hashtag.ToggleHashtag\x1a\x14.social.common.Emptyb\x06proto3')



_HASHTAG = DESCRIPTOR.message_types_by_name['Hashtag']
_HASHTAGSTAT = DESCRIPTOR.message_types_by_name['HashtagStat']
_FINDRESPONSE = DESCRIPTOR.message_types_by_name['FindResponse']
_GETFEEDREQUEST = DESCRIPTOR.message_types_by_name['GetFeedRequest']
_GETFEEDRESPONSE = DESCRIPTOR.message_types_by_name['GetFeedResponse']
_GETHASHTAGFOLLOWINGRESPONSE = DESCRIPTOR.message_types_by_name['GetHashtagFollowingResponse']
_TOGGLEHASHTAG = DESCRIPTOR.message_types_by_name['ToggleHashtag']
Hashtag = _reflection.GeneratedProtocolMessageType('Hashtag', (_message.Message,), {
  'DESCRIPTOR' : _HASHTAG,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.Hashtag)
  })
_sym_db.RegisterMessage(Hashtag)

HashtagStat = _reflection.GeneratedProtocolMessageType('HashtagStat', (_message.Message,), {
  'DESCRIPTOR' : _HASHTAGSTAT,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.HashtagStat)
  })
_sym_db.RegisterMessage(HashtagStat)

FindResponse = _reflection.GeneratedProtocolMessageType('FindResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDRESPONSE,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.FindResponse)
  })
_sym_db.RegisterMessage(FindResponse)

GetFeedRequest = _reflection.GeneratedProtocolMessageType('GetFeedRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEEDREQUEST,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.GetFeedRequest)
  })
_sym_db.RegisterMessage(GetFeedRequest)

GetFeedResponse = _reflection.GeneratedProtocolMessageType('GetFeedResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEEDRESPONSE,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.GetFeedResponse)
  })
_sym_db.RegisterMessage(GetFeedResponse)

GetHashtagFollowingResponse = _reflection.GeneratedProtocolMessageType('GetHashtagFollowingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETHASHTAGFOLLOWINGRESPONSE,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.GetHashtagFollowingResponse)
  })
_sym_db.RegisterMessage(GetHashtagFollowingResponse)

ToggleHashtag = _reflection.GeneratedProtocolMessageType('ToggleHashtag', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEHASHTAG,
  '__module__' : 'services.hashtag.hashtag_pb2'
  # @@protoc_insertion_point(class_scope:social.hashtag.ToggleHashtag)
  })
_sym_db.RegisterMessage(ToggleHashtag)

_HASHTAGSERVICE = DESCRIPTOR.services_by_name['HashtagService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HASHTAG._serialized_start=138
  _HASHTAG._serialized_end=256
  _HASHTAGSTAT._serialized_start=258
  _HASHTAGSTAT._serialized_end=338
  _FINDRESPONSE._serialized_start=340
  _FINDRESPONSE._serialized_end=394
  _GETFEEDREQUEST._serialized_start=396
  _GETFEEDREQUEST._serialized_end=485
  _GETFEEDRESPONSE._serialized_start=487
  _GETFEEDRESPONSE._serialized_end=580
  _GETHASHTAGFOLLOWINGRESPONSE._serialized_start=582
  _GETHASHTAGFOLLOWINGRESPONSE._serialized_end=651
  _TOGGLEHASHTAG._serialized_start=653
  _TOGGLEHASHTAG._serialized_end=703
  _HASHTAGSERVICE._serialized_start=706
  _HASHTAGSERVICE._serialized_end=1282
# @@protoc_insertion_point(module_scope)
