# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/discussion/discussion.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$services/discussion/discussion.proto\x12\x06social\x1a\x1cservices/common/common.proto\x1a\x1eservices/account/account.proto\"\xe9\x01\n\nDiscussion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x11\n\tparent_id\x18\x03 \x01(\t\x12(\n\x07\x61\x63\x63ount\x18\x04 \x01(\x0b\x32\x17.social.account.Account\x12\x0c\n\x04\x62ody\x18\x05 \x01(\t\x12\x14\n\x0cpublished_at\x18\x06 \x01(\x03\x12\x12\n\ndeleted_at\x18\x07 \x01(\x03\x12$\n\x04stat\x18\x08 \x01(\x0b\x32\x16.social.DiscussionStat\x12\x10\n\x08is_liked\x18\t \x01(\x08\x12\x11\n\tis_pinned\x18\n \x01(\x08\"9\n\x0e\x44iscussionStat\x12\x12\n\nlike_count\x18\x01 \x01(\x03\x12\x13\n\x0breply_count\x18\x02 \x01(\x03\";\n\x16\x44iscussionListResponse\x12!\n\x05items\x18\x01 \x03(\x0b\x32\x12.social.Discussion\"Z\n\x15GetDiscussionsRequest\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\"8\n\x10ToggleDiscussion\x12\x15\n\rdiscussion_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\x32\x89\x05\n\x11\x44iscussionService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12\x31\n\x07Publish\x12\x12.social.Discussion\x1a\x12.social.Discussion\x12\x32\n\x06Update\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12\x32\n\x06\x44\x65lete\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12O\n\x0eGetDiscussions\x12\x1d.social.GetDiscussionsRequest\x1a\x1e.social.DiscussionListResponse\x12\x30\n\x04Like\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12\x33\n\x07\x44islike\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12/\n\x03Pin\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12\x31\n\x05UnPin\x12\x12.social.Discussion\x1a\x14.social.common.Empty\x12G\n\x15\x41\x64minDiscussionDelete\x12\x18.social.ToggleDiscussion\x1a\x14.social.common.Empty\x12\x41\n\x15\x41\x64minDiscussionUpdate\x12\x12.social.Discussion\x1a\x14.social.common.Emptyb\x06proto3')



_DISCUSSION = DESCRIPTOR.message_types_by_name['Discussion']
_DISCUSSIONSTAT = DESCRIPTOR.message_types_by_name['DiscussionStat']
_DISCUSSIONLISTRESPONSE = DESCRIPTOR.message_types_by_name['DiscussionListResponse']
_GETDISCUSSIONSREQUEST = DESCRIPTOR.message_types_by_name['GetDiscussionsRequest']
_TOGGLEDISCUSSION = DESCRIPTOR.message_types_by_name['ToggleDiscussion']
Discussion = _reflection.GeneratedProtocolMessageType('Discussion', (_message.Message,), {
  'DESCRIPTOR' : _DISCUSSION,
  '__module__' : 'services.discussion.discussion_pb2'
  # @@protoc_insertion_point(class_scope:social.Discussion)
  })
_sym_db.RegisterMessage(Discussion)

DiscussionStat = _reflection.GeneratedProtocolMessageType('DiscussionStat', (_message.Message,), {
  'DESCRIPTOR' : _DISCUSSIONSTAT,
  '__module__' : 'services.discussion.discussion_pb2'
  # @@protoc_insertion_point(class_scope:social.DiscussionStat)
  })
_sym_db.RegisterMessage(DiscussionStat)

DiscussionListResponse = _reflection.GeneratedProtocolMessageType('DiscussionListResponse', (_message.Message,), {
  'DESCRIPTOR' : _DISCUSSIONLISTRESPONSE,
  '__module__' : 'services.discussion.discussion_pb2'
  # @@protoc_insertion_point(class_scope:social.DiscussionListResponse)
  })
_sym_db.RegisterMessage(DiscussionListResponse)

GetDiscussionsRequest = _reflection.GeneratedProtocolMessageType('GetDiscussionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDISCUSSIONSREQUEST,
  '__module__' : 'services.discussion.discussion_pb2'
  # @@protoc_insertion_point(class_scope:social.GetDiscussionsRequest)
  })
_sym_db.RegisterMessage(GetDiscussionsRequest)

ToggleDiscussion = _reflection.GeneratedProtocolMessageType('ToggleDiscussion', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEDISCUSSION,
  '__module__' : 'services.discussion.discussion_pb2'
  # @@protoc_insertion_point(class_scope:social.ToggleDiscussion)
  })
_sym_db.RegisterMessage(ToggleDiscussion)

_DISCUSSIONSERVICE = DESCRIPTOR.services_by_name['DiscussionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DISCUSSION._serialized_start=111
  _DISCUSSION._serialized_end=344
  _DISCUSSIONSTAT._serialized_start=346
  _DISCUSSIONSTAT._serialized_end=403
  _DISCUSSIONLISTRESPONSE._serialized_start=405
  _DISCUSSIONLISTRESPONSE._serialized_end=464
  _GETDISCUSSIONSREQUEST._serialized_start=466
  _GETDISCUSSIONSREQUEST._serialized_end=556
  _TOGGLEDISCUSSION._serialized_start=558
  _TOGGLEDISCUSSION._serialized_end=614
  _DISCUSSIONSERVICE._serialized_start=617
  _DISCUSSIONSERVICE._serialized_end=1266
# @@protoc_insertion_point(module_scope)
