# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/story/story.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2
from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aservices/story/story.proto\x12\x0csocial.story\x1a\x1eservices/account/account.proto\x1a\x1cservices/common/common.proto\"\xfd\x01\n\x05Story\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12(\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32\x17.social.account.Account\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x12\n\nhyper_link\x18\x05 \x01(\t\x12\x14\n\x0cpublished_at\x18\x06 \x01(\x03\x12\x12\n\ndeleted_at\x18\x07 \x01(\x03\x12(\n\nmedia_list\x18\x08 \x03(\x0b\x32\x14.social.common.Media\x12\x0f\n\x07is_seen\x18\t \x01(\x08\x12%\n\x04stat\x18\n \x01(\x0b\x32\x17.social.story.StoryStat\"\x1f\n\tStoryStat\x12\x12\n\nview_count\x18\x01 \x01(\x03\"^\n\x0fGetStoryRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x18\n\x10\x61\x63\x63ount_username\x18\x04 \x01(\t\"H\n\rStoryResponse\x12\"\n\x05story\x18\x01 \x01(\x0b\x32\x13.social.story.Story\x12\x13\n\x0b\x63hecked_all\x18\x02 \x01(\x08\"L\n\x11StoryListResponse\x12\"\n\x05items\x18\x01 \x03(\x0b\x32\x13.social.story.Story\x12\x13\n\x0bis_seen_all\x18\x02 \x01(\x08\"N\n\rStoryFeedItem\x12(\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x17.social.account.Account\x12\x13\n\x0bis_seen_all\x18\x02 \x01(\x08\"4\n\x13GetStoryFeedRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\r\n\x05limit\x18\x02 \x01(\x05\"?\n\x11StoryFeedResponse\x12*\n\x05items\x18\x01 \x03(\x0b\x32\x1b.social.story.StoryFeedItem\".\n\x0bToggleStory\x12\x10\n\x08story_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\x32\xf3\x04\n\x0cStoryService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12Y\n\x10UploadStoryMedia\x12!.social.common.UploadMediaRequest\x1a\".social.common.UploadMediaResponse\x12\x38\n\x0cPublishStory\x12\x13.social.story.Story\x1a\x13.social.story.Story\x12\x38\n\x0b\x44\x65leteStory\x12\x13.social.story.Story\x1a\x14.social.common.Empty\x12\x34\n\x08GetStory\x12\x13.social.story.Story\x1a\x13.social.story.Story\x12L\n\nGetStories\x12\x1d.social.story.GetStoryRequest\x1a\x1f.social.story.StoryListResponse\x12M\n\x07GetFeed\x12!.social.story.GetStoryFeedRequest\x1a\x1f.social.story.StoryFeedResponse\x12I\n\x0bGetArchives\x12\x19.social.common.Pagination\x1a\x1f.social.story.StoryListResponse\x12\x43\n\x10\x41\x64minStoryDelete\x12\x19.social.story.ToggleStory\x1a\x14.social.common.Emptyb\x06proto3')



_STORY = DESCRIPTOR.message_types_by_name['Story']
_STORYSTAT = DESCRIPTOR.message_types_by_name['StoryStat']
_GETSTORYREQUEST = DESCRIPTOR.message_types_by_name['GetStoryRequest']
_STORYRESPONSE = DESCRIPTOR.message_types_by_name['StoryResponse']
_STORYLISTRESPONSE = DESCRIPTOR.message_types_by_name['StoryListResponse']
_STORYFEEDITEM = DESCRIPTOR.message_types_by_name['StoryFeedItem']
_GETSTORYFEEDREQUEST = DESCRIPTOR.message_types_by_name['GetStoryFeedRequest']
_STORYFEEDRESPONSE = DESCRIPTOR.message_types_by_name['StoryFeedResponse']
_TOGGLESTORY = DESCRIPTOR.message_types_by_name['ToggleStory']
Story = _reflection.GeneratedProtocolMessageType('Story', (_message.Message,), {
  'DESCRIPTOR' : _STORY,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.Story)
  })
_sym_db.RegisterMessage(Story)

StoryStat = _reflection.GeneratedProtocolMessageType('StoryStat', (_message.Message,), {
  'DESCRIPTOR' : _STORYSTAT,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.StoryStat)
  })
_sym_db.RegisterMessage(StoryStat)

GetStoryRequest = _reflection.GeneratedProtocolMessageType('GetStoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORYREQUEST,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.GetStoryRequest)
  })
_sym_db.RegisterMessage(GetStoryRequest)

StoryResponse = _reflection.GeneratedProtocolMessageType('StoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORYRESPONSE,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.StoryResponse)
  })
_sym_db.RegisterMessage(StoryResponse)

StoryListResponse = _reflection.GeneratedProtocolMessageType('StoryListResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORYLISTRESPONSE,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.StoryListResponse)
  })
_sym_db.RegisterMessage(StoryListResponse)

StoryFeedItem = _reflection.GeneratedProtocolMessageType('StoryFeedItem', (_message.Message,), {
  'DESCRIPTOR' : _STORYFEEDITEM,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.StoryFeedItem)
  })
_sym_db.RegisterMessage(StoryFeedItem)

GetStoryFeedRequest = _reflection.GeneratedProtocolMessageType('GetStoryFeedRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORYFEEDREQUEST,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.GetStoryFeedRequest)
  })
_sym_db.RegisterMessage(GetStoryFeedRequest)

StoryFeedResponse = _reflection.GeneratedProtocolMessageType('StoryFeedResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORYFEEDRESPONSE,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.StoryFeedResponse)
  })
_sym_db.RegisterMessage(StoryFeedResponse)

ToggleStory = _reflection.GeneratedProtocolMessageType('ToggleStory', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLESTORY,
  '__module__' : 'services.story.story_pb2'
  # @@protoc_insertion_point(class_scope:social.story.ToggleStory)
  })
_sym_db.RegisterMessage(ToggleStory)

_STORYSERVICE = DESCRIPTOR.services_by_name['StoryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STORY._serialized_start=107
  _STORY._serialized_end=360
  _STORYSTAT._serialized_start=362
  _STORYSTAT._serialized_end=393
  _GETSTORYREQUEST._serialized_start=395
  _GETSTORYREQUEST._serialized_end=489
  _STORYRESPONSE._serialized_start=491
  _STORYRESPONSE._serialized_end=563
  _STORYLISTRESPONSE._serialized_start=565
  _STORYLISTRESPONSE._serialized_end=641
  _STORYFEEDITEM._serialized_start=643
  _STORYFEEDITEM._serialized_end=721
  _GETSTORYFEEDREQUEST._serialized_start=723
  _GETSTORYFEEDREQUEST._serialized_end=775
  _STORYFEEDRESPONSE._serialized_start=777
  _STORYFEEDRESPONSE._serialized_end=840
  _TOGGLESTORY._serialized_start=842
  _TOGGLESTORY._serialized_end=888
  _STORYSERVICE._serialized_start=891
  _STORYSERVICE._serialized_end=1518
# @@protoc_insertion_point(module_scope)
