# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/stats/stats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aservices/stats/stats.proto\x12\x0csocial.stats\x1a\x1cservices/common/common.proto\x1a\x1eservices/account/account.proto\"!\n\x04Stat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03obj\x18\x02 \x01(\t\"L\n\x10GetActorsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03obj\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\"<\n\x11GetActorsResponse\x12\'\n\x06\x61\x63tors\x18\x01 \x03(\x0b\x32\x17.social.account.Account\"&\n\x11IncrementResponse\x12\x11\n\tis_insert\x18\x01 \x01(\x08\"&\n\x11\x44\x65\x63rementResponse\x12\x11\n\tis_delete\x18\x01 \x01(\x08\x32\xcb\x02\n\x0cStatsService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12@\n\tIncrement\x12\x12.social.stats.Stat\x1a\x1f.social.stats.IncrementResponse\x12@\n\tDecrement\x12\x12.social.stats.Stat\x1a\x1f.social.stats.DecrementResponse\x12\x36\n\x05\x43ount\x12\x12.social.stats.Stat\x1a\x19.social.common.Int64Value\x12L\n\tGetActors\x12\x1e.social.stats.GetActorsRequest\x1a\x1f.social.stats.GetActorsResponseb\x06proto3')



_STAT = DESCRIPTOR.message_types_by_name['Stat']
_GETACTORSREQUEST = DESCRIPTOR.message_types_by_name['GetActorsRequest']
_GETACTORSRESPONSE = DESCRIPTOR.message_types_by_name['GetActorsResponse']
_INCREMENTRESPONSE = DESCRIPTOR.message_types_by_name['IncrementResponse']
_DECREMENTRESPONSE = DESCRIPTOR.message_types_by_name['DecrementResponse']
Stat = _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), {
  'DESCRIPTOR' : _STAT,
  '__module__' : 'services.stats.stats_pb2'
  # @@protoc_insertion_point(class_scope:social.stats.Stat)
  })
_sym_db.RegisterMessage(Stat)

GetActorsRequest = _reflection.GeneratedProtocolMessageType('GetActorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORSREQUEST,
  '__module__' : 'services.stats.stats_pb2'
  # @@protoc_insertion_point(class_scope:social.stats.GetActorsRequest)
  })
_sym_db.RegisterMessage(GetActorsRequest)

GetActorsResponse = _reflection.GeneratedProtocolMessageType('GetActorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACTORSRESPONSE,
  '__module__' : 'services.stats.stats_pb2'
  # @@protoc_insertion_point(class_scope:social.stats.GetActorsResponse)
  })
_sym_db.RegisterMessage(GetActorsResponse)

IncrementResponse = _reflection.GeneratedProtocolMessageType('IncrementResponse', (_message.Message,), {
  'DESCRIPTOR' : _INCREMENTRESPONSE,
  '__module__' : 'services.stats.stats_pb2'
  # @@protoc_insertion_point(class_scope:social.stats.IncrementResponse)
  })
_sym_db.RegisterMessage(IncrementResponse)

DecrementResponse = _reflection.GeneratedProtocolMessageType('DecrementResponse', (_message.Message,), {
  'DESCRIPTOR' : _DECREMENTRESPONSE,
  '__module__' : 'services.stats.stats_pb2'
  # @@protoc_insertion_point(class_scope:social.stats.DecrementResponse)
  })
_sym_db.RegisterMessage(DecrementResponse)

_STATSSERVICE = DESCRIPTOR.services_by_name['StatsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STAT._serialized_start=106
  _STAT._serialized_end=139
  _GETACTORSREQUEST._serialized_start=141
  _GETACTORSREQUEST._serialized_end=217
  _GETACTORSRESPONSE._serialized_start=219
  _GETACTORSRESPONSE._serialized_end=279
  _INCREMENTRESPONSE._serialized_start=281
  _INCREMENTRESPONSE._serialized_end=319
  _DECREMENTRESPONSE._serialized_start=321
  _DECREMENTRESPONSE._serialized_end=359
  _STATSSERVICE._serialized_start=362
  _STATSSERVICE._serialized_end=693
# @@protoc_insertion_point(module_scope)
