# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/mention/mention.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.post import post_pb2 as services_dot_post_dot_post__pb2
from common.api.services.story import story_pb2 as services_dot_story_dot_story__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/mention/mention.proto\x12\x0esocial.mention\x1a\x1cservices/common/common.proto\x1a\x18services/post/post.proto\x1a\x1aservices/story/story.proto\"d\n\x15GetMentionedInRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x18\n\x10\x61\x63\x63ount_username\x18\x04 \x01(\t2\x81\x02\n\x0eMentionService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12[\n\x13GetMentionedInPosts\x12%.social.mention.GetMentionedInRequest\x1a\x1d.social.post.PostListResponse\x12_\n\x15GetMentionedInStories\x12%.social.mention.GetMentionedInRequest\x1a\x1f.social.story.StoryListResponseb\x06proto3')



_GETMENTIONEDINREQUEST = DESCRIPTOR.message_types_by_name['GetMentionedInRequest']
GetMentionedInRequest = _reflection.GeneratedProtocolMessageType('GetMentionedInRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMENTIONEDINREQUEST,
  '__module__' : 'services.mention.mention_pb2'
  # @@protoc_insertion_point(class_scope:social.mention.GetMentionedInRequest)
  })
_sym_db.RegisterMessage(GetMentionedInRequest)

_MENTIONSERVICE = DESCRIPTOR.services_by_name['MentionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETMENTIONEDINREQUEST._serialized_start=134
  _GETMENTIONEDINREQUEST._serialized_end=234
  _MENTIONSERVICE._serialized_start=237
  _MENTIONSERVICE._serialized_end=494
# @@protoc_insertion_point(module_scope)
