# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.post import post_pb2 as services_dot_post_dot_post__pb2


class PostServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/social.post.PostService/Ping',
                request_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Pong.FromString,
                )
        self.UploadPostMedia = channel.unary_unary(
                '/social.post.PostService/UploadPostMedia',
                request_serializer=services_dot_common_dot_common__pb2.UploadMediaRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.UploadMediaResponse.FromString,
                )
        self.PublishPost = channel.unary_unary(
                '/social.post.PostService/PublishPost',
                request_serializer=services_dot_post_dot_post__pb2.Post.SerializeToString,
                response_deserializer=services_dot_post_dot_post__pb2.Post.FromString,
                )
        self.UpdatePost = channel.unary_unary(
                '/social.post.PostService/UpdatePost',
                request_serializer=services_dot_post_dot_post__pb2.Post.SerializeToString,
                response_deserializer=services_dot_post_dot_post__pb2.Post.FromString,
                )
        self.DeletePost = channel.unary_unary(
                '/social.post.PostService/DeletePost',
                request_serializer=services_dot_post_dot_post__pb2.Post.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.GetPost = channel.unary_unary(
                '/social.post.PostService/GetPost',
                request_serializer=services_dot_post_dot_post__pb2.Post.SerializeToString,
                response_deserializer=services_dot_post_dot_post__pb2.Post.FromString,
                )
        self.GetPosts = channel.unary_unary(
                '/social.post.PostService/GetPosts',
                request_serializer=services_dot_post_dot_post__pb2.GetPostsRequest.SerializeToString,
                response_deserializer=services_dot_post_dot_post__pb2.PostListResponse.FromString,
                )
        self.GetFeed = channel.unary_unary(
                '/social.post.PostService/GetFeed',
                request_serializer=services_dot_post_dot_post__pb2.GetPostsRequest.SerializeToString,
                response_deserializer=services_dot_post_dot_post__pb2.PostListResponse.FromString,
                )
        self.Find = channel.unary_unary(
                '/social.post.PostService/Find',
                request_serializer=services_dot_common_dot_common__pb2.FindRequest.SerializeToString,
                response_deserializer=services_dot_post_dot_post__pb2.PostListResponse.FromString,
                )
        self.GetSavedPosts = channel.unary_unary(
                '/social.post.PostService/GetSavedPosts',
                request_serializer=services_dot_post_dot_post__pb2.GetSavedPostsRequest.SerializeToString,
                response_deserializer=services_dot_post_dot_post__pb2.PostListResponse.FromString,
                )
        self.SavePost = channel.unary_unary(
                '/social.post.PostService/SavePost',
                request_serializer=services_dot_post_dot_post__pb2.SavePostRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.UnSavePost = channel.unary_unary(
                '/social.post.PostService/UnSavePost',
                request_serializer=services_dot_post_dot_post__pb2.SavePostRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.GetArchivedPosts = channel.unary_unary(
                '/social.post.PostService/GetArchivedPosts',
                request_serializer=services_dot_common_dot_common__pb2.Pagination.SerializeToString,
                response_deserializer=services_dot_post_dot_post__pb2.PostListResponse.FromString,
                )
        self.ArchivePost = channel.unary_unary(
                '/social.post.PostService/ArchivePost',
                request_serializer=services_dot_post_dot_post__pb2.Post.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.UnArchivedPost = channel.unary_unary(
                '/social.post.PostService/UnArchivedPost',
                request_serializer=services_dot_post_dot_post__pb2.Post.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.GetPostsCats = channel.unary_unary(
                '/social.post.PostService/GetPostsCats',
                request_serializer=services_dot_common_dot_common__pb2.Pagination.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.CatListResponse.FromString,
                )
        self.CreateSaveCat = channel.unary_unary(
                '/social.post.PostService/CreateSaveCat',
                request_serializer=services_dot_common_dot_common__pb2.Category.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Category.FromString,
                )
        self.DeleteSaveCat = channel.unary_unary(
                '/social.post.PostService/DeleteSaveCat',
                request_serializer=services_dot_common_dot_common__pb2.Category.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.GetPostsByLocation = channel.unary_unary(
                '/social.post.PostService/GetPostsByLocation',
                request_serializer=services_dot_post_dot_post__pb2.GetPostsByLocationRequest.SerializeToString,
                response_deserializer=services_dot_post_dot_post__pb2.PostListResponse.FromString,
                )
        self.Like = channel.unary_unary(
                '/social.post.PostService/Like',
                request_serializer=services_dot_post_dot_post__pb2.LikeRequest.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminPostArchive = channel.unary_unary(
                '/social.post.PostService/AdminPostArchive',
                request_serializer=services_dot_post_dot_post__pb2.TogglePost.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminPostDelete = channel.unary_unary(
                '/social.post.PostService/AdminPostDelete',
                request_serializer=services_dot_post_dot_post__pb2.TogglePost.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminPostUpdate = channel.unary_unary(
                '/social.post.PostService/AdminPostUpdate',
                request_serializer=services_dot_post_dot_post__pb2.Post.SerializeToString,
                response_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                )
        self.AdminInstagramCrawler = channel.stream_stream(
                '/social.post.PostService/AdminInstagramCrawler',
                request_serializer=services_dot_post_dot_post__pb2.InstagramCrawlerRequest.SerializeToString,
                response_deserializer=services_dot_post_dot_post__pb2.InstagramCrawlerResponse.FromString,
                )


class PostServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadPostMedia(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishPost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPosts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Find(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSavedPosts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SavePost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnSavePost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetArchivedPosts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArchivePost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnArchivedPost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPostsCats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSaveCat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSaveCat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPostsByLocation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Like(self, request, context):
        """root
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminPostArchive(self, request, context):
        """Admin Section. All admin services starts with `AdminSERVICE_NAME`
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminPostDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminPostUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdminInstagramCrawler(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PostServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=services_dot_common_dot_common__pb2.Empty.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Pong.SerializeToString,
            ),
            'UploadPostMedia': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadPostMedia,
                    request_deserializer=services_dot_common_dot_common__pb2.UploadMediaRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.UploadMediaResponse.SerializeToString,
            ),
            'PublishPost': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishPost,
                    request_deserializer=services_dot_post_dot_post__pb2.Post.FromString,
                    response_serializer=services_dot_post_dot_post__pb2.Post.SerializeToString,
            ),
            'UpdatePost': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePost,
                    request_deserializer=services_dot_post_dot_post__pb2.Post.FromString,
                    response_serializer=services_dot_post_dot_post__pb2.Post.SerializeToString,
            ),
            'DeletePost': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePost,
                    request_deserializer=services_dot_post_dot_post__pb2.Post.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'GetPost': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPost,
                    request_deserializer=services_dot_post_dot_post__pb2.Post.FromString,
                    response_serializer=services_dot_post_dot_post__pb2.Post.SerializeToString,
            ),
            'GetPosts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPosts,
                    request_deserializer=services_dot_post_dot_post__pb2.GetPostsRequest.FromString,
                    response_serializer=services_dot_post_dot_post__pb2.PostListResponse.SerializeToString,
            ),
            'GetFeed': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeed,
                    request_deserializer=services_dot_post_dot_post__pb2.GetPostsRequest.FromString,
                    response_serializer=services_dot_post_dot_post__pb2.PostListResponse.SerializeToString,
            ),
            'Find': grpc.unary_unary_rpc_method_handler(
                    servicer.Find,
                    request_deserializer=services_dot_common_dot_common__pb2.FindRequest.FromString,
                    response_serializer=services_dot_post_dot_post__pb2.PostListResponse.SerializeToString,
            ),
            'GetSavedPosts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSavedPosts,
                    request_deserializer=services_dot_post_dot_post__pb2.GetSavedPostsRequest.FromString,
                    response_serializer=services_dot_post_dot_post__pb2.PostListResponse.SerializeToString,
            ),
            'SavePost': grpc.unary_unary_rpc_method_handler(
                    servicer.SavePost,
                    request_deserializer=services_dot_post_dot_post__pb2.SavePostRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'UnSavePost': grpc.unary_unary_rpc_method_handler(
                    servicer.UnSavePost,
                    request_deserializer=services_dot_post_dot_post__pb2.SavePostRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'GetArchivedPosts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetArchivedPosts,
                    request_deserializer=services_dot_common_dot_common__pb2.Pagination.FromString,
                    response_serializer=services_dot_post_dot_post__pb2.PostListResponse.SerializeToString,
            ),
            'ArchivePost': grpc.unary_unary_rpc_method_handler(
                    servicer.ArchivePost,
                    request_deserializer=services_dot_post_dot_post__pb2.Post.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'UnArchivedPost': grpc.unary_unary_rpc_method_handler(
                    servicer.UnArchivedPost,
                    request_deserializer=services_dot_post_dot_post__pb2.Post.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'GetPostsCats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPostsCats,
                    request_deserializer=services_dot_common_dot_common__pb2.Pagination.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.CatListResponse.SerializeToString,
            ),
            'CreateSaveCat': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSaveCat,
                    request_deserializer=services_dot_common_dot_common__pb2.Category.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Category.SerializeToString,
            ),
            'DeleteSaveCat': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSaveCat,
                    request_deserializer=services_dot_common_dot_common__pb2.Category.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'GetPostsByLocation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPostsByLocation,
                    request_deserializer=services_dot_post_dot_post__pb2.GetPostsByLocationRequest.FromString,
                    response_serializer=services_dot_post_dot_post__pb2.PostListResponse.SerializeToString,
            ),
            'Like': grpc.unary_unary_rpc_method_handler(
                    servicer.Like,
                    request_deserializer=services_dot_post_dot_post__pb2.LikeRequest.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminPostArchive': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminPostArchive,
                    request_deserializer=services_dot_post_dot_post__pb2.TogglePost.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminPostDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminPostDelete,
                    request_deserializer=services_dot_post_dot_post__pb2.TogglePost.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminPostUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.AdminPostUpdate,
                    request_deserializer=services_dot_post_dot_post__pb2.Post.FromString,
                    response_serializer=services_dot_common_dot_common__pb2.Empty.SerializeToString,
            ),
            'AdminInstagramCrawler': grpc.stream_stream_rpc_method_handler(
                    servicer.AdminInstagramCrawler,
                    request_deserializer=services_dot_post_dot_post__pb2.InstagramCrawlerRequest.FromString,
                    response_serializer=services_dot_post_dot_post__pb2.InstagramCrawlerResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'social.post.PostService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PostService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/Ping',
            services_dot_common_dot_common__pb2.Empty.SerializeToString,
            services_dot_common_dot_common__pb2.Pong.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadPostMedia(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/UploadPostMedia',
            services_dot_common_dot_common__pb2.UploadMediaRequest.SerializeToString,
            services_dot_common_dot_common__pb2.UploadMediaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PublishPost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/PublishPost',
            services_dot_post_dot_post__pb2.Post.SerializeToString,
            services_dot_post_dot_post__pb2.Post.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/UpdatePost',
            services_dot_post_dot_post__pb2.Post.SerializeToString,
            services_dot_post_dot_post__pb2.Post.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/DeletePost',
            services_dot_post_dot_post__pb2.Post.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/GetPost',
            services_dot_post_dot_post__pb2.Post.SerializeToString,
            services_dot_post_dot_post__pb2.Post.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/GetPosts',
            services_dot_post_dot_post__pb2.GetPostsRequest.SerializeToString,
            services_dot_post_dot_post__pb2.PostListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/GetFeed',
            services_dot_post_dot_post__pb2.GetPostsRequest.SerializeToString,
            services_dot_post_dot_post__pb2.PostListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Find(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/Find',
            services_dot_common_dot_common__pb2.FindRequest.SerializeToString,
            services_dot_post_dot_post__pb2.PostListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSavedPosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/GetSavedPosts',
            services_dot_post_dot_post__pb2.GetSavedPostsRequest.SerializeToString,
            services_dot_post_dot_post__pb2.PostListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SavePost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/SavePost',
            services_dot_post_dot_post__pb2.SavePostRequest.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnSavePost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/UnSavePost',
            services_dot_post_dot_post__pb2.SavePostRequest.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetArchivedPosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/GetArchivedPosts',
            services_dot_common_dot_common__pb2.Pagination.SerializeToString,
            services_dot_post_dot_post__pb2.PostListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArchivePost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/ArchivePost',
            services_dot_post_dot_post__pb2.Post.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnArchivedPost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/UnArchivedPost',
            services_dot_post_dot_post__pb2.Post.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPostsCats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/GetPostsCats',
            services_dot_common_dot_common__pb2.Pagination.SerializeToString,
            services_dot_common_dot_common__pb2.CatListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSaveCat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/CreateSaveCat',
            services_dot_common_dot_common__pb2.Category.SerializeToString,
            services_dot_common_dot_common__pb2.Category.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSaveCat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/DeleteSaveCat',
            services_dot_common_dot_common__pb2.Category.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPostsByLocation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/GetPostsByLocation',
            services_dot_post_dot_post__pb2.GetPostsByLocationRequest.SerializeToString,
            services_dot_post_dot_post__pb2.PostListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Like(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/Like',
            services_dot_post_dot_post__pb2.LikeRequest.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminPostArchive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/AdminPostArchive',
            services_dot_post_dot_post__pb2.TogglePost.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminPostDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/AdminPostDelete',
            services_dot_post_dot_post__pb2.TogglePost.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminPostUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/social.post.PostService/AdminPostUpdate',
            services_dot_post_dot_post__pb2.Post.SerializeToString,
            services_dot_common_dot_common__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdminInstagramCrawler(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/social.post.PostService/AdminInstagramCrawler',
            services_dot_post_dot_post__pb2.InstagramCrawlerRequest.SerializeToString,
            services_dot_post_dot_post__pb2.InstagramCrawlerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
