# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/post/post.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2
from common.api.services.account import account_pb2 as services_dot_account_dot_account__pb2
from common.api.services.discussion import discussion_pb2 as services_dot_discussion_dot_discussion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18services/post/post.proto\x12\x0bsocial.post\x1a\x1cservices/common/common.proto\x1a\x1eservices/account/account.proto\x1a$services/discussion/discussion.proto\">\n\tRelatedTo\x12%\n\x03typ\x18\x01 \x01(\x0e\x32\x18.social.post.RelatedType\x12\n\n\x02to\x18\x02 \x01(\t\"\xbb\x03\n\x04Post\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61ption\x18\x02 \x01(\t\x12)\n\x08location\x18\x03 \x01(\x0b\x32\x17.social.common.Location\x12(\n\x07\x61\x63\x63ount\x18\x04 \x01(\x0b\x32\x17.social.account.Account\x12\x14\n\x0cpublished_at\x18\x05 \x01(\x03\x12\x13\n\x0b\x61rchived_at\x18\x06 \x01(\x03\x12\x12\n\ndeleted_at\x18\x07 \x01(\x03\x12\x1b\n\x13is_disabled_comment\x18\x08 \x01(\x08\x12\x18\n\x10is_disabled_stat\x18\t \x01(\x08\x12#\n\x04stat\x18\n \x01(\x0b\x32\x15.social.post.PostStat\x12(\n\nmedia_list\x18\x0b \x03(\x0b\x32\x14.social.common.Media\x12\x10\n\x08is_liked\x18\x0c \x01(\x08\x12\x10\n\x08is_saved\x18\r \x01(\x08\x12,\n\x10preview_comments\x18\x0e \x03(\x0b\x32\x12.social.Discussion\x12*\n\nrelated_to\x18\x0f \x01(\x0b\x32\x16.social.post.RelatedTo\"I\n\x08PostStat\x12\x12\n\nlike_count\x18\x01 \x01(\x03\x12\x12\n\nview_count\x18\x02 \x01(\x03\x12\x15\n\rcomment_count\x18\x03 \x01(\x03\"4\n\x10PostListResponse\x12 \n\x05items\x18\x01 \x03(\x0b\x32\x11.social.post.Post\"^\n\x0fGetPostsRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x18\n\x10\x61\x63\x63ount_username\x18\x05 \x01(\t\"E\n\x14GetSavedPostsRequest\x12\x0e\n\x06\x63\x61t_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"B\n\x0fSavePostRequest\x12\x0e\n\x06\x63\x61t_id\x18\x01 \x01(\t\x12\x1f\n\x04post\x18\x02 \x01(\x0b\x32\x11.social.post.Post\"=\n\x0bLikeRequest\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\r\n\x05\x61\x63tor\x18\x03 \x01(\t\"U\n\x19GetPostsByLocationRequest\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0c\n\x04long\x18\x02 \x01(\x01\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\",\n\nTogglePost\x12\x0f\n\x07post_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"7\n\x17InstagramCrawlerRequest\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\t\">\n\x18InstagramCrawlerResponse\x12\x12\n\nnext_field\x18\x01 \x01(\t\x12\x0e\n\x06output\x18\x02 \x01(\t*8\n\x0bRelatedType\x12\x0b\n\x07TO_POST\x10\x00\x12\x0e\n\nTO_PRODUCT\x10\x01\x12\x0c\n\x08TO_STYLE\x10\x02\x32\xe3\x0c\n\x0bPostService\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12X\n\x0fUploadPostMedia\x12!.social.common.UploadMediaRequest\x1a\".social.common.UploadMediaResponse\x12\x33\n\x0bPublishPost\x12\x11.social.post.Post\x1a\x11.social.post.Post\x12\x32\n\nUpdatePost\x12\x11.social.post.Post\x1a\x11.social.post.Post\x12\x35\n\nDeletePost\x12\x11.social.post.Post\x1a\x14.social.common.Empty\x12/\n\x07GetPost\x12\x11.social.post.Post\x1a\x11.social.post.Post\x12G\n\x08GetPosts\x12\x1c.social.post.GetPostsRequest\x1a\x1d.social.post.PostListResponse\x12\x46\n\x07GetFeed\x12\x1c.social.post.GetPostsRequest\x1a\x1d.social.post.PostListResponse\x12\x41\n\x04\x46ind\x12\x1a.social.common.FindRequest\x1a\x1d.social.post.PostListResponse\x12Q\n\rGetSavedPosts\x12!.social.post.GetSavedPostsRequest\x1a\x1d.social.post.PostListResponse\x12>\n\x08SavePost\x12\x1c.social.post.SavePostRequest\x1a\x14.social.common.Empty\x12@\n\nUnSavePost\x12\x1c.social.post.SavePostRequest\x1a\x14.social.common.Empty\x12L\n\x10GetArchivedPosts\x12\x19.social.common.Pagination\x1a\x1d.social.post.PostListResponse\x12\x36\n\x0b\x41rchivePost\x12\x11.social.post.Post\x1a\x14.social.common.Empty\x12\x39\n\x0eUnArchivedPost\x12\x11.social.post.Post\x1a\x14.social.common.Empty\x12I\n\x0cGetPostsCats\x12\x19.social.common.Pagination\x1a\x1e.social.common.CatListResponse\x12\x41\n\rCreateSaveCat\x12\x17.social.common.Category\x1a\x17.social.common.Category\x12>\n\rDeleteSaveCat\x12\x17.social.common.Category\x1a\x14.social.common.Empty\x12[\n\x12GetPostsByLocation\x12&.social.post.GetPostsByLocationRequest\x1a\x1d.social.post.PostListResponse\x12\x36\n\x04Like\x12\x18.social.post.LikeRequest\x1a\x14.social.common.Empty\x12\x41\n\x10\x41\x64minPostArchive\x12\x17.social.post.TogglePost\x1a\x14.social.common.Empty\x12@\n\x0f\x41\x64minPostDelete\x12\x17.social.post.TogglePost\x1a\x14.social.common.Empty\x12:\n\x0f\x41\x64minPostUpdate\x12\x11.social.post.Post\x1a\x14.social.common.Empty\x12h\n\x15\x41\x64minInstagramCrawler\x12$.social.post.InstagramCrawlerRequest\x1a%.social.post.InstagramCrawlerResponse(\x01\x30\x01\x62\x06proto3')

_RELATEDTYPE = DESCRIPTOR.enum_types_by_name['RelatedType']
RelatedType = enum_type_wrapper.EnumTypeWrapper(_RELATEDTYPE)
TO_POST = 0
TO_PRODUCT = 1
TO_STYLE = 2


_RELATEDTO = DESCRIPTOR.message_types_by_name['RelatedTo']
_POST = DESCRIPTOR.message_types_by_name['Post']
_POSTSTAT = DESCRIPTOR.message_types_by_name['PostStat']
_POSTLISTRESPONSE = DESCRIPTOR.message_types_by_name['PostListResponse']
_GETPOSTSREQUEST = DESCRIPTOR.message_types_by_name['GetPostsRequest']
_GETSAVEDPOSTSREQUEST = DESCRIPTOR.message_types_by_name['GetSavedPostsRequest']
_SAVEPOSTREQUEST = DESCRIPTOR.message_types_by_name['SavePostRequest']
_LIKEREQUEST = DESCRIPTOR.message_types_by_name['LikeRequest']
_GETPOSTSBYLOCATIONREQUEST = DESCRIPTOR.message_types_by_name['GetPostsByLocationRequest']
_TOGGLEPOST = DESCRIPTOR.message_types_by_name['TogglePost']
_INSTAGRAMCRAWLERREQUEST = DESCRIPTOR.message_types_by_name['InstagramCrawlerRequest']
_INSTAGRAMCRAWLERRESPONSE = DESCRIPTOR.message_types_by_name['InstagramCrawlerResponse']
RelatedTo = _reflection.GeneratedProtocolMessageType('RelatedTo', (_message.Message,), {
  'DESCRIPTOR' : _RELATEDTO,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.RelatedTo)
  })
_sym_db.RegisterMessage(RelatedTo)

Post = _reflection.GeneratedProtocolMessageType('Post', (_message.Message,), {
  'DESCRIPTOR' : _POST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.Post)
  })
_sym_db.RegisterMessage(Post)

PostStat = _reflection.GeneratedProtocolMessageType('PostStat', (_message.Message,), {
  'DESCRIPTOR' : _POSTSTAT,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.PostStat)
  })
_sym_db.RegisterMessage(PostStat)

PostListResponse = _reflection.GeneratedProtocolMessageType('PostListResponse', (_message.Message,), {
  'DESCRIPTOR' : _POSTLISTRESPONSE,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.PostListResponse)
  })
_sym_db.RegisterMessage(PostListResponse)

GetPostsRequest = _reflection.GeneratedProtocolMessageType('GetPostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTSREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.GetPostsRequest)
  })
_sym_db.RegisterMessage(GetPostsRequest)

GetSavedPostsRequest = _reflection.GeneratedProtocolMessageType('GetSavedPostsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSAVEDPOSTSREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.GetSavedPostsRequest)
  })
_sym_db.RegisterMessage(GetSavedPostsRequest)

SavePostRequest = _reflection.GeneratedProtocolMessageType('SavePostRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAVEPOSTREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.SavePostRequest)
  })
_sym_db.RegisterMessage(SavePostRequest)

LikeRequest = _reflection.GeneratedProtocolMessageType('LikeRequest', (_message.Message,), {
  'DESCRIPTOR' : _LIKEREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.LikeRequest)
  })
_sym_db.RegisterMessage(LikeRequest)

GetPostsByLocationRequest = _reflection.GeneratedProtocolMessageType('GetPostsByLocationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTSBYLOCATIONREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.GetPostsByLocationRequest)
  })
_sym_db.RegisterMessage(GetPostsByLocationRequest)

TogglePost = _reflection.GeneratedProtocolMessageType('TogglePost', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEPOST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.TogglePost)
  })
_sym_db.RegisterMessage(TogglePost)

InstagramCrawlerRequest = _reflection.GeneratedProtocolMessageType('InstagramCrawlerRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSTAGRAMCRAWLERREQUEST,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.InstagramCrawlerRequest)
  })
_sym_db.RegisterMessage(InstagramCrawlerRequest)

InstagramCrawlerResponse = _reflection.GeneratedProtocolMessageType('InstagramCrawlerResponse', (_message.Message,), {
  'DESCRIPTOR' : _INSTAGRAMCRAWLERRESPONSE,
  '__module__' : 'services.post.post_pb2'
  # @@protoc_insertion_point(class_scope:social.post.InstagramCrawlerResponse)
  })
_sym_db.RegisterMessage(InstagramCrawlerResponse)

_POSTSERVICE = DESCRIPTOR.services_by_name['PostService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RELATEDTYPE._serialized_start=1332
  _RELATEDTYPE._serialized_end=1388
  _RELATEDTO._serialized_start=141
  _RELATEDTO._serialized_end=203
  _POST._serialized_start=206
  _POST._serialized_end=649
  _POSTSTAT._serialized_start=651
  _POSTSTAT._serialized_end=724
  _POSTLISTRESPONSE._serialized_start=726
  _POSTLISTRESPONSE._serialized_end=778
  _GETPOSTSREQUEST._serialized_start=780
  _GETPOSTSREQUEST._serialized_end=874
  _GETSAVEDPOSTSREQUEST._serialized_start=876
  _GETSAVEDPOSTSREQUEST._serialized_end=945
  _SAVEPOSTREQUEST._serialized_start=947
  _SAVEPOSTREQUEST._serialized_end=1013
  _LIKEREQUEST._serialized_start=1015
  _LIKEREQUEST._serialized_end=1076
  _GETPOSTSBYLOCATIONREQUEST._serialized_start=1078
  _GETPOSTSBYLOCATIONREQUEST._serialized_end=1163
  _TOGGLEPOST._serialized_start=1165
  _TOGGLEPOST._serialized_end=1209
  _INSTAGRAMCRAWLERREQUEST._serialized_start=1211
  _INSTAGRAMCRAWLERREQUEST._serialized_end=1266
  _INSTAGRAMCRAWLERRESPONSE._serialized_start=1268
  _INSTAGRAMCRAWLERRESPONSE._serialized_end=1330
  _POSTSERVICE._serialized_start=1391
  _POSTSERVICE._serialized_end=3026
# @@protoc_insertion_point(module_scope)
