# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services/account/account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.api.services.common import common_pb2 as services_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eservices/account/account.proto\x12\x0esocial.account\x1a\x1cservices/common/common.proto\"\\\n\x18\x43\x61rtPublishStatusRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x0epublish_status\x18\x02 \x01(\x0b\x32\x1c.social.common.PublishStatus\"\x97\x01\n\nCreditCard\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\t\x12\r\n\x05shaba\x18\x03 \x01(\t\x12\x13\n\x0b\x63\x61rd_holder\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x34\n\x0epublish_status\x18\x06 \x01(\x0b\x32\x1c.social.common.PublishStatus\"C\n\x16\x43reditCardListResponse\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.social.account.CreditCard\"N\n\x16\x41\x63\x63ountAddressReceiver\x12\x12\n\nfirst_name\x18\x01 \x01(\t\x12\x11\n\tlast_name\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\t\"\xa7\x02\n\x0e\x41\x63\x63ountAddress\x12\n\n\x02id\x18\x01 \x01(\t\x12(\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x17.social.account.Account\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\x12\x15\n\rneighbourhood\x18\x06 \x01(\t\x12\x0e\n\x06plaque\x18\x07 \x01(\t\x12\x0c\n\x04unit\x18\x08 \x01(\t\x12\x38\n\x08receiver\x18\t \x01(\x0b\x32&.social.account.AccountAddressReceiver\x12\x13\n\x0bpostal_code\x18\n \x01(\t\x12\x0b\n\x03lat\x18\x0b \x01(\x01\x12\x0c\n\x04long\x18\x0c \x01(\x01\x12\x12\n\nis_default\x18\r \x01(\x08\"D\n\x13\x41\x64\x64ressListResponse\x12-\n\x05items\x18\x01 \x03(\x0b\x32\x1e.social.account.AccountAddress\"\x17\n\x05phone\x12\x0e\n\x06number\x18\x01 \x01(\t\">\n\x13SyncContactsRequest\x12\'\n\x08\x63ontacts\x18\x01 \x03(\x0b\x32\x15.social.account.phone\"K\n\x14SetVisibilityRequest\x12\x33\n\nvisibility\x18\x01 \x01(\x0e\x32\x1f.social.account.VisibilityTypes\".\n\x0eSendOtpRequest\x12\r\n\x05phone\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"%\n\x0fSendOtpResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"8\n\x10VerifyOtpRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"s\n\x11VerifyOtpResponse\x12$\n\x05token\x18\x01 \x01(\x0b\x32\x15.social.account.Token\x12(\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x17.social.account.Account\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\"\xf1\x04\n\x07\x41\x63\x63ount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nnetwork_id\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\r\n\x05phone\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12\x10\n\x08password\x18\x07 \x01(\t\x12+\n\x06gender\x18\x08 \x01(\x0e\x32\x1b.social.account.GenderTypes\x12\x0b\n\x03\x62io\x18\t \x01(\t\x12\x13\n\x0bwebsite_url\x18\n \x01(\t\x12\x12\n\navatar_url\x18\x0b \x01(\t\x12\x10\n\x08\x62irthday\x18\x0c \x01(\x03\x12\x12\n\ncreated_at\x18\r \x01(\x03\x12\x13\n\x0b\x64isabled_at\x18\x0e \x01(\x03\x12\x12\n\ndeleted_at\x18\x0f \x01(\x03\x12\x11\n\tbanned_at\x18\x10 \x01(\x03\x12\x33\n\nvisibility\x18\x11 \x01(\x0e\x32\x1f.social.account.VisibilityTypes\x12\x12\n\nis_blocker\x18\x12 \x01(\x08\x12\x13\n\x0bis_blocking\x18\x13 \x01(\x08\x12)\n\x04stat\x18\x14 \x01(\x0b\x32\x1b.social.account.AccountStat\x12\x13\n\x0bis_verified\x18\x15 \x01(\x08\x12\x35\n\x08\x62usiness\x18\x16 \x01(\x0b\x32#.social.account.BusinessInformation\x12\x32\n\x0cnotification\x18\x17 \x01(\x0b\x32\x1c.social.account.Notification\x12\x12\n\nhas_avatar\x18\x18 \x01(\x08\x12\x0c\n\x04role\x18\x19 \x01(\t\"X\n\x13\x42usinessInformation\x12\r\n\x05phone\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x03 \x01(\t\x12\x11\n\tis_active\x18\x04 \x01(\x08\"v\n\x0cNotification\x12\n\n\x02on\x18\x01 \x01(\x08\x12\x0c\n\x04like\x18\x02 \x01(\x05\x12\x0e\n\x06\x66ollow\x18\x03 \x01(\x05\x12\x15\n\raccept_follow\x18\x04 \x01(\x05\x12\x0f\n\x07\x63omment\x18\x05 \x01(\x05\x12\x14\n\x0c\x63omment_like\x18\x06 \x01(\x05\"5\n\x08\x41\x63\x63ounts\x12)\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x17.social.account.Account\"\x90\x01\n\x0b\x41\x63\x63ountStat\x12\x12\n\npost_count\x18\x01 \x01(\x03\x12\x16\n\x0e\x66ollower_count\x18\x02 \x01(\x03\x12\x17\n\x0f\x66ollowing_count\x18\x03 \x01(\x03\x12\x13\n\x0bis_follower\x18\x04 \x01(\x05\x12\x14\n\x0cis_following\x18\x05 \x01(\x05\x12\x11\n\thas_story\x18\x06 \x01(\x08\"G\n\x12\x41\x63\x63ountListRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"=\n\x13\x41\x63\x63ountListResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.account.Account\"4\n\x05Token\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\"4\n\x13GetBlackListRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x05\x12\r\n\x05limit\x18\x02 \x01(\x05\",\n\x13RefreshTokenRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"<\n\x14RefreshTokenResponse\x12$\n\x05token\x18\x01 \x01(\x0b\x32\x15.social.account.Token\"S\n\x14GetFollowingResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.account.Account\x12\x13\n\x0bhas_hashtag\x18\x02 \x01(\x08\"(\n\x14\x43heckUsernameRequest\x12\x10\n\x08username\x18\x01 \x01(\t\")\n\nSMSRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\r\n\x05phone\x18\x02 \x01(\t\"\"\n\x0bSMSResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\"\xb0\x01\n\x07Session\x12\n\n\x02id\x18\n \x01(\t\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65vice_model\x18\x02 \x01(\t\x12\x11\n\tfcm_token\x18\x03 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\x05\x12\x0f\n\x07\x61pp_ver\x18\x05 \x01(\t\x12\x0e\n\x06os_ver\x18\x06 \x01(\t\x12\x0e\n\x06locale\x18\x07 \x01(\t\x12\n\n\x02ip\x18\x08 \x01(\t\x12\x10\n\x08login_at\x18\t \x01(\x03\"=\n\x13SessionListResponse\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.social.account.Session\"2\n\rToggleAccount\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"{\n\x04Role\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0bpermissions\x18\x04 \x03(\t\x12\x11\n\tis_active\x18\x05 \x01(\x08\x12\x1c\n\x14login_to_admin_panel\x18\x06 \x01(\x08\"7\n\x10RoleListResponse\x12#\n\x05items\x18\x01 \x03(\x0b\x32\x14.social.account.Role\"8\n\x0eRolePermission\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x15\n\rpermission_id\x18\x02 \x03(\t\"8\n\x11\x41ssignRoleRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0f\n\x07role_id\x18\x02 \x01(\t\"X\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nclass_name\x18\x03 \x01(\t\x12\x15\n\rfunction_name\x18\x04 \x01(\t\"C\n\x16PermissionListResponse\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.social.account.Permission\"D\n\x12RoleAccountRequest\x12\x0f\n\x07role_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\"(\n\x12\x41\x63\x63ountRoleRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t*7\n\x0fVisibilityTypes\x12\n\n\x06PUBLIC\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\x0b\n\x07NETWORK\x10\x02*-\n\x0bGenderTypes\x12\x08\n\x04None\x10\x00\x12\x08\n\x04MALE\x10\x01\x12\n\n\x06\x46\x45MALE\x10\x02\x32\xfc\'\n\x0e\x41\x63\x63ountService\x12J\n\x07SendOtp\x12\x1e.social.account.SendOtpRequest\x1a\x1f.social.account.SendOtpResponse\x12P\n\tVerifyOtp\x12 .social.account.VerifyOtpRequest\x1a!.social.account.VerifyOtpResponse\x12\x46\n\x08Register\x12\x17.social.account.Account\x1a!.social.account.VerifyOtpResponse\x12\x34\n\x06LogOut\x12\x14.social.common.Empty\x1a\x14.social.common.Empty\x12>\n\nGetProfile\x12\x17.social.account.Account\x1a\x17.social.account.Account\x12\x41\n\x0bGetProfiles\x12\x18.social.account.Accounts\x1a\x18.social.account.Accounts\x12\x41\n\rUpdateProfile\x12\x17.social.account.Account\x1a\x17.social.account.Account\x12L\n\x16GetNotificationSetting\x12\x14.social.common.Empty\x1a\x1c.social.account.Notification\x12O\n\x19UpdateNotificationSetting\x12\x1c.social.account.Notification\x1a\x14.social.common.Empty\x12G\n\x04\x46ind\x12\x1a.social.common.FindRequest\x1a#.social.account.AccountListResponse\x12?\n\x06\x44\x65lete\x12\x14.social.common.Empty\x1a\x1f.social.account.SendOtpResponse\x12\x46\n\x0c\x44\x65leteVerify\x12 .social.account.VerifyOtpRequest\x1a\x14.social.common.Empty\x12\x31\n\x04Ping\x12\x14.social.common.Empty\x1a\x13.social.common.Pong\x12\x37\n\x06\x46ollow\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12\x39\n\x08Unfollow\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12\x36\n\x05\x42lock\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12\x38\n\x07Unblock\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12X\n\x0cGetBlockList\x12#.social.account.GetBlackListRequest\x1a#.social.account.AccountListResponse\x12W\n\x0cGetFollowers\x12\".social.account.AccountListRequest\x1a#.social.account.AccountListResponse\x12X\n\x0cGetFollowing\x12\".social.account.AccountListRequest\x1a$.social.account.GetFollowingResponse\x12\\\n\x11GetFollowRequests\x12\".social.account.AccountListRequest\x1a#.social.account.AccountListResponse\x12Y\n\x0cRefreshToken\x12#.social.account.RefreshTokenRequest\x1a$.social.account.RefreshTokenResponse\x12N\n\x12UploadProfilePhoto\x12\x14.social.common.Empty\x1a\".social.common.UploadMediaResponse\x12\x44\n\x13\x41\x63\x63\x65ptFollowRequest\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12\x44\n\x13RejectFollowRequest\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12K\n\rSetVisibility\x12$.social.account.SetVisibilityRequest\x1a\x14.social.common.Empty\x12Z\n\x18GetPendingFollowRequests\x12\x19.social.common.Pagination\x1a#.social.account.AccountListResponse\x12\x43\n\x0bisFollowing\x12\x17.social.account.Account\x1a\x1b.social.common.BooleanValue\x12\x42\n\nisFollower\x12\x17.social.account.Account\x1a\x1b.social.common.BooleanValue\x12X\n\x13isUsernameAvailable\x12$.social.account.CheckUsernameRequest\x1a\x1b.social.common.BooleanValue\x12\x42\n\nisVerified\x12\x17.social.account.Account\x1a\x1b.social.common.BooleanValue\x12J\n\x19ToggleAccountVerification\x12\x17.social.account.Account\x1a\x14.social.common.Empty\x12?\n\x11ToggleAccountType\x12\x14.social.common.Empty\x1a\x14.social.common.Empty\x12=\n\x0cSetPushToken\x12\x17.social.account.Session\x1a\x14.social.common.Empty\x12I\n\x0cSyncContacts\x12#.social.account.SyncContactsRequest\x1a\x14.social.common.Empty\x12M\n\x0bSuggestions\x12\x19.social.common.Pagination\x1a#.social.account.AccountListResponse\x12\x42\n\nAddAddress\x12\x1e.social.account.AccountAddress\x1a\x14.social.common.Empty\x12\x45\n\rUpdateAddress\x12\x1e.social.account.AccountAddress\x1a\x14.social.common.Empty\x12\x45\n\rDeleteAddress\x12\x1e.social.account.AccountAddress\x1a\x14.social.common.Empty\x12Q\n\x0fGetAllAddresses\x12\x19.social.common.Pagination\x1a#.social.account.AddressListResponse\x12I\n\x11SetDefaultAddress\x12\x1e.social.account.AccountAddress\x1a\x14.social.common.Empty\x12\x41\n\rAddCreditCard\x12\x1a.social.account.CreditCard\x1a\x14.social.common.Empty\x12\x44\n\x10UpdateCreditCard\x12\x1a.social.account.CreditCard\x1a\x14.social.common.Empty\x12\x44\n\x10\x44\x65leteCreditCard\x12\x1a.social.account.CreditCard\x1a\x14.social.common.Empty\x12V\n\x11GetAllCreditCards\x12\x19.social.common.Pagination\x1a&.social.account.CreditCardListResponse\x12_\n\x1d\x41\x64minAccountApproveCreditCard\x12(.social.account.CartPublishStatusRequest\x1a\x14.social.common.Empty\x12^\n\x1c\x41\x64minAccountRejectCreditCard\x12(.social.account.CartPublishStatusRequest\x1a\x14.social.common.Empty\x12M\n\x0bGetSessions\x12\x19.social.common.Pagination\x1a#.social.account.SessionListResponse\x12G\n\x0fisSessionActive\x12\x17.social.account.Session\x1a\x1b.social.common.BooleanValue\x12>\n\rDeleteSession\x12\x17.social.account.Session\x1a\x14.social.common.Empty\x12J\n\x13\x41\x64minAccountDisable\x12\x1d.social.account.ToggleAccount\x1a\x14.social.common.Empty\x12I\n\x12\x41\x64minAccountDelete\x12\x1d.social.account.ToggleAccount\x1a\x14.social.common.Empty\x12I\n\x12\x41\x64minAccountVerify\x12\x1d.social.account.ToggleAccount\x1a\x14.social.common.Empty\x12\x46\n\x0f\x41\x64minAccountBan\x12\x1d.social.account.ToggleAccount\x1a\x14.social.common.Empty\x12\x46\n\x12\x41\x64minAccountUpdate\x12\x17.social.account.Account\x1a\x17.social.account.Account\x12Q\n\x0f\x41\x64minAccountAll\x12\x19.social.common.Pagination\x1a#.social.account.AccountListResponse\x12O\n\x0c\x41\x64minSendOTP\x12\x1e.social.account.SendOtpRequest\x1a\x1f.social.account.SendOtpResponse\x12<\n\x0eRootCreateRole\x12\x14.social.account.Role\x1a\x14.social.account.Role\x12<\n\x0eRootUpdateRole\x12\x14.social.account.Role\x1a\x14.social.common.Empty\x12<\n\x0eRootDeleteRole\x12\x14.social.account.Role\x1a\x14.social.common.Empty\x12N\n\x0fRootGetAllRoles\x12\x19.social.common.Pagination\x1a .social.account.RoleListResponse\x12O\n\x17RootAddPermissionToRole\x12\x1e.social.account.RolePermission\x1a\x14.social.common.Empty\x12T\n\x1cRootRemovePermissionFromRole\x12\x1e.social.account.RolePermission\x1a\x14.social.common.Empty\x12I\n\x0eRootAssignRole\x12!.social.account.AssignRoleRequest\x1a\x14.social.common.Empty\x12K\n\x10RootUnassignRole\x12!.social.account.AssignRoleRequest\x1a\x14.social.common.Empty\x12U\n\x15RootGetAllPermissions\x12\x14.social.common.Empty\x1a&.social.account.PermissionListResponse\x12\x63\n\x18RootGetAllAccountsInRole\x12\".social.account.RoleAccountRequest\x1a#.social.account.AccountListResponse\x12[\n\x13RootGetAccountRoles\x12\".social.account.AccountRoleRequest\x1a .social.account.RoleListResponseb\x06proto3')

_VISIBILITYTYPES = DESCRIPTOR.enum_types_by_name['VisibilityTypes']
VisibilityTypes = enum_type_wrapper.EnumTypeWrapper(_VISIBILITYTYPES)
_GENDERTYPES = DESCRIPTOR.enum_types_by_name['GenderTypes']
GenderTypes = enum_type_wrapper.EnumTypeWrapper(_GENDERTYPES)
PUBLIC = 0
PRIVATE = 1
NETWORK = 2
globals()['None'] = 0
MALE = 1
FEMALE = 2


_CARTPUBLISHSTATUSREQUEST = DESCRIPTOR.message_types_by_name['CartPublishStatusRequest']
_CREDITCARD = DESCRIPTOR.message_types_by_name['CreditCard']
_CREDITCARDLISTRESPONSE = DESCRIPTOR.message_types_by_name['CreditCardListResponse']
_ACCOUNTADDRESSRECEIVER = DESCRIPTOR.message_types_by_name['AccountAddressReceiver']
_ACCOUNTADDRESS = DESCRIPTOR.message_types_by_name['AccountAddress']
_ADDRESSLISTRESPONSE = DESCRIPTOR.message_types_by_name['AddressListResponse']
_PHONE = DESCRIPTOR.message_types_by_name['phone']
_SYNCCONTACTSREQUEST = DESCRIPTOR.message_types_by_name['SyncContactsRequest']
_SETVISIBILITYREQUEST = DESCRIPTOR.message_types_by_name['SetVisibilityRequest']
_SENDOTPREQUEST = DESCRIPTOR.message_types_by_name['SendOtpRequest']
_SENDOTPRESPONSE = DESCRIPTOR.message_types_by_name['SendOtpResponse']
_VERIFYOTPREQUEST = DESCRIPTOR.message_types_by_name['VerifyOtpRequest']
_VERIFYOTPRESPONSE = DESCRIPTOR.message_types_by_name['VerifyOtpResponse']
_ACCOUNT = DESCRIPTOR.message_types_by_name['Account']
_BUSINESSINFORMATION = DESCRIPTOR.message_types_by_name['BusinessInformation']
_NOTIFICATION = DESCRIPTOR.message_types_by_name['Notification']
_ACCOUNTS = DESCRIPTOR.message_types_by_name['Accounts']
_ACCOUNTSTAT = DESCRIPTOR.message_types_by_name['AccountStat']
_ACCOUNTLISTREQUEST = DESCRIPTOR.message_types_by_name['AccountListRequest']
_ACCOUNTLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccountListResponse']
_TOKEN = DESCRIPTOR.message_types_by_name['Token']
_GETBLACKLISTREQUEST = DESCRIPTOR.message_types_by_name['GetBlackListRequest']
_REFRESHTOKENREQUEST = DESCRIPTOR.message_types_by_name['RefreshTokenRequest']
_REFRESHTOKENRESPONSE = DESCRIPTOR.message_types_by_name['RefreshTokenResponse']
_GETFOLLOWINGRESPONSE = DESCRIPTOR.message_types_by_name['GetFollowingResponse']
_CHECKUSERNAMEREQUEST = DESCRIPTOR.message_types_by_name['CheckUsernameRequest']
_SMSREQUEST = DESCRIPTOR.message_types_by_name['SMSRequest']
_SMSRESPONSE = DESCRIPTOR.message_types_by_name['SMSResponse']
_SESSION = DESCRIPTOR.message_types_by_name['Session']
_SESSIONLISTRESPONSE = DESCRIPTOR.message_types_by_name['SessionListResponse']
_TOGGLEACCOUNT = DESCRIPTOR.message_types_by_name['ToggleAccount']
_ROLE = DESCRIPTOR.message_types_by_name['Role']
_ROLELISTRESPONSE = DESCRIPTOR.message_types_by_name['RoleListResponse']
_ROLEPERMISSION = DESCRIPTOR.message_types_by_name['RolePermission']
_ASSIGNROLEREQUEST = DESCRIPTOR.message_types_by_name['AssignRoleRequest']
_PERMISSION = DESCRIPTOR.message_types_by_name['Permission']
_PERMISSIONLISTRESPONSE = DESCRIPTOR.message_types_by_name['PermissionListResponse']
_ROLEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['RoleAccountRequest']
_ACCOUNTROLEREQUEST = DESCRIPTOR.message_types_by_name['AccountRoleRequest']
CartPublishStatusRequest = _reflection.GeneratedProtocolMessageType('CartPublishStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CARTPUBLISHSTATUSREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.CartPublishStatusRequest)
  })
_sym_db.RegisterMessage(CartPublishStatusRequest)

CreditCard = _reflection.GeneratedProtocolMessageType('CreditCard', (_message.Message,), {
  'DESCRIPTOR' : _CREDITCARD,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.CreditCard)
  })
_sym_db.RegisterMessage(CreditCard)

CreditCardListResponse = _reflection.GeneratedProtocolMessageType('CreditCardListResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREDITCARDLISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.CreditCardListResponse)
  })
_sym_db.RegisterMessage(CreditCardListResponse)

AccountAddressReceiver = _reflection.GeneratedProtocolMessageType('AccountAddressReceiver', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTADDRESSRECEIVER,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountAddressReceiver)
  })
_sym_db.RegisterMessage(AccountAddressReceiver)

AccountAddress = _reflection.GeneratedProtocolMessageType('AccountAddress', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTADDRESS,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountAddress)
  })
_sym_db.RegisterMessage(AccountAddress)

AddressListResponse = _reflection.GeneratedProtocolMessageType('AddressListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSLISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AddressListResponse)
  })
_sym_db.RegisterMessage(AddressListResponse)

phone = _reflection.GeneratedProtocolMessageType('phone', (_message.Message,), {
  'DESCRIPTOR' : _PHONE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.phone)
  })
_sym_db.RegisterMessage(phone)

SyncContactsRequest = _reflection.GeneratedProtocolMessageType('SyncContactsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNCCONTACTSREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SyncContactsRequest)
  })
_sym_db.RegisterMessage(SyncContactsRequest)

SetVisibilityRequest = _reflection.GeneratedProtocolMessageType('SetVisibilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETVISIBILITYREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SetVisibilityRequest)
  })
_sym_db.RegisterMessage(SetVisibilityRequest)

SendOtpRequest = _reflection.GeneratedProtocolMessageType('SendOtpRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDOTPREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SendOtpRequest)
  })
_sym_db.RegisterMessage(SendOtpRequest)

SendOtpResponse = _reflection.GeneratedProtocolMessageType('SendOtpResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDOTPRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SendOtpResponse)
  })
_sym_db.RegisterMessage(SendOtpResponse)

VerifyOtpRequest = _reflection.GeneratedProtocolMessageType('VerifyOtpRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYOTPREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.VerifyOtpRequest)
  })
_sym_db.RegisterMessage(VerifyOtpRequest)

VerifyOtpResponse = _reflection.GeneratedProtocolMessageType('VerifyOtpResponse', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYOTPRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.VerifyOtpResponse)
  })
_sym_db.RegisterMessage(VerifyOtpResponse)

Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNT,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Account)
  })
_sym_db.RegisterMessage(Account)

BusinessInformation = _reflection.GeneratedProtocolMessageType('BusinessInformation', (_message.Message,), {
  'DESCRIPTOR' : _BUSINESSINFORMATION,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.BusinessInformation)
  })
_sym_db.RegisterMessage(BusinessInformation)

Notification = _reflection.GeneratedProtocolMessageType('Notification', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATION,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Notification)
  })
_sym_db.RegisterMessage(Notification)

Accounts = _reflection.GeneratedProtocolMessageType('Accounts', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTS,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Accounts)
  })
_sym_db.RegisterMessage(Accounts)

AccountStat = _reflection.GeneratedProtocolMessageType('AccountStat', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTSTAT,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountStat)
  })
_sym_db.RegisterMessage(AccountStat)

AccountListRequest = _reflection.GeneratedProtocolMessageType('AccountListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTLISTREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountListRequest)
  })
_sym_db.RegisterMessage(AccountListRequest)

AccountListResponse = _reflection.GeneratedProtocolMessageType('AccountListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTLISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountListResponse)
  })
_sym_db.RegisterMessage(AccountListResponse)

Token = _reflection.GeneratedProtocolMessageType('Token', (_message.Message,), {
  'DESCRIPTOR' : _TOKEN,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Token)
  })
_sym_db.RegisterMessage(Token)

GetBlackListRequest = _reflection.GeneratedProtocolMessageType('GetBlackListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLACKLISTREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.GetBlackListRequest)
  })
_sym_db.RegisterMessage(GetBlackListRequest)

RefreshTokenRequest = _reflection.GeneratedProtocolMessageType('RefreshTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _REFRESHTOKENREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.RefreshTokenRequest)
  })
_sym_db.RegisterMessage(RefreshTokenRequest)

RefreshTokenResponse = _reflection.GeneratedProtocolMessageType('RefreshTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _REFRESHTOKENRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.RefreshTokenResponse)
  })
_sym_db.RegisterMessage(RefreshTokenResponse)

GetFollowingResponse = _reflection.GeneratedProtocolMessageType('GetFollowingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFOLLOWINGRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.GetFollowingResponse)
  })
_sym_db.RegisterMessage(GetFollowingResponse)

CheckUsernameRequest = _reflection.GeneratedProtocolMessageType('CheckUsernameRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKUSERNAMEREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.CheckUsernameRequest)
  })
_sym_db.RegisterMessage(CheckUsernameRequest)

SMSRequest = _reflection.GeneratedProtocolMessageType('SMSRequest', (_message.Message,), {
  'DESCRIPTOR' : _SMSREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SMSRequest)
  })
_sym_db.RegisterMessage(SMSRequest)

SMSResponse = _reflection.GeneratedProtocolMessageType('SMSResponse', (_message.Message,), {
  'DESCRIPTOR' : _SMSRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SMSResponse)
  })
_sym_db.RegisterMessage(SMSResponse)

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), {
  'DESCRIPTOR' : _SESSION,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Session)
  })
_sym_db.RegisterMessage(Session)

SessionListResponse = _reflection.GeneratedProtocolMessageType('SessionListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONLISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.SessionListResponse)
  })
_sym_db.RegisterMessage(SessionListResponse)

ToggleAccount = _reflection.GeneratedProtocolMessageType('ToggleAccount', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEACCOUNT,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.ToggleAccount)
  })
_sym_db.RegisterMessage(ToggleAccount)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Role)
  })
_sym_db.RegisterMessage(Role)

RoleListResponse = _reflection.GeneratedProtocolMessageType('RoleListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLELISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.RoleListResponse)
  })
_sym_db.RegisterMessage(RoleListResponse)

RolePermission = _reflection.GeneratedProtocolMessageType('RolePermission', (_message.Message,), {
  'DESCRIPTOR' : _ROLEPERMISSION,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.RolePermission)
  })
_sym_db.RegisterMessage(RolePermission)

AssignRoleRequest = _reflection.GeneratedProtocolMessageType('AssignRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASSIGNROLEREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AssignRoleRequest)
  })
_sym_db.RegisterMessage(AssignRoleRequest)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.Permission)
  })
_sym_db.RegisterMessage(Permission)

PermissionListResponse = _reflection.GeneratedProtocolMessageType('PermissionListResponse', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSIONLISTRESPONSE,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.PermissionListResponse)
  })
_sym_db.RegisterMessage(PermissionListResponse)

RoleAccountRequest = _reflection.GeneratedProtocolMessageType('RoleAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEACCOUNTREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.RoleAccountRequest)
  })
_sym_db.RegisterMessage(RoleAccountRequest)

AccountRoleRequest = _reflection.GeneratedProtocolMessageType('AccountRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTROLEREQUEST,
  '__module__' : 'services.account.account_pb2'
  # @@protoc_insertion_point(class_scope:social.account.AccountRoleRequest)
  })
_sym_db.RegisterMessage(AccountRoleRequest)

_ACCOUNTSERVICE = DESCRIPTOR.services_by_name['AccountService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VISIBILITYTYPES._serialized_start=3734
  _VISIBILITYTYPES._serialized_end=3789
  _GENDERTYPES._serialized_start=3791
  _GENDERTYPES._serialized_end=3836
  _CARTPUBLISHSTATUSREQUEST._serialized_start=80
  _CARTPUBLISHSTATUSREQUEST._serialized_end=172
  _CREDITCARD._serialized_start=175
  _CREDITCARD._serialized_end=326
  _CREDITCARDLISTRESPONSE._serialized_start=328
  _CREDITCARDLISTRESPONSE._serialized_end=395
  _ACCOUNTADDRESSRECEIVER._serialized_start=397
  _ACCOUNTADDRESSRECEIVER._serialized_end=475
  _ACCOUNTADDRESS._serialized_start=478
  _ACCOUNTADDRESS._serialized_end=773
  _ADDRESSLISTRESPONSE._serialized_start=775
  _ADDRESSLISTRESPONSE._serialized_end=843
  _PHONE._serialized_start=845
  _PHONE._serialized_end=868
  _SYNCCONTACTSREQUEST._serialized_start=870
  _SYNCCONTACTSREQUEST._serialized_end=932
  _SETVISIBILITYREQUEST._serialized_start=934
  _SETVISIBILITYREQUEST._serialized_end=1009
  _SENDOTPREQUEST._serialized_start=1011
  _SENDOTPREQUEST._serialized_end=1057
  _SENDOTPRESPONSE._serialized_start=1059
  _SENDOTPRESPONSE._serialized_end=1096
  _VERIFYOTPREQUEST._serialized_start=1098
  _VERIFYOTPREQUEST._serialized_end=1154
  _VERIFYOTPRESPONSE._serialized_start=1156
  _VERIFYOTPRESPONSE._serialized_end=1271
  _ACCOUNT._serialized_start=1274
  _ACCOUNT._serialized_end=1899
  _BUSINESSINFORMATION._serialized_start=1901
  _BUSINESSINFORMATION._serialized_end=1989
  _NOTIFICATION._serialized_start=1991
  _NOTIFICATION._serialized_end=2109
  _ACCOUNTS._serialized_start=2111
  _ACCOUNTS._serialized_end=2164
  _ACCOUNTSTAT._serialized_start=2167
  _ACCOUNTSTAT._serialized_end=2311
  _ACCOUNTLISTREQUEST._serialized_start=2313
  _ACCOUNTLISTREQUEST._serialized_end=2384
  _ACCOUNTLISTRESPONSE._serialized_start=2386
  _ACCOUNTLISTRESPONSE._serialized_end=2447
  _TOKEN._serialized_start=2449
  _TOKEN._serialized_end=2501
  _GETBLACKLISTREQUEST._serialized_start=2503
  _GETBLACKLISTREQUEST._serialized_end=2555
  _REFRESHTOKENREQUEST._serialized_start=2557
  _REFRESHTOKENREQUEST._serialized_end=2601
  _REFRESHTOKENRESPONSE._serialized_start=2603
  _REFRESHTOKENRESPONSE._serialized_end=2663
  _GETFOLLOWINGRESPONSE._serialized_start=2665
  _GETFOLLOWINGRESPONSE._serialized_end=2748
  _CHECKUSERNAMEREQUEST._serialized_start=2750
  _CHECKUSERNAMEREQUEST._serialized_end=2790
  _SMSREQUEST._serialized_start=2792
  _SMSREQUEST._serialized_end=2833
  _SMSRESPONSE._serialized_start=2835
  _SMSRESPONSE._serialized_end=2869
  _SESSION._serialized_start=2872
  _SESSION._serialized_end=3048
  _SESSIONLISTRESPONSE._serialized_start=3050
  _SESSIONLISTRESPONSE._serialized_end=3111
  _TOGGLEACCOUNT._serialized_start=3113
  _TOGGLEACCOUNT._serialized_end=3163
  _ROLE._serialized_start=3165
  _ROLE._serialized_end=3288
  _ROLELISTRESPONSE._serialized_start=3290
  _ROLELISTRESPONSE._serialized_end=3345
  _ROLEPERMISSION._serialized_start=3347
  _ROLEPERMISSION._serialized_end=3403
  _ASSIGNROLEREQUEST._serialized_start=3405
  _ASSIGNROLEREQUEST._serialized_end=3461
  _PERMISSION._serialized_start=3463
  _PERMISSION._serialized_end=3551
  _PERMISSIONLISTRESPONSE._serialized_start=3553
  _PERMISSIONLISTRESPONSE._serialized_end=3620
  _ROLEACCOUNTREQUEST._serialized_start=3622
  _ROLEACCOUNTREQUEST._serialized_end=3690
  _ACCOUNTROLEREQUEST._serialized_start=3692
  _ACCOUNTROLEREQUEST._serialized_end=3732
  _ACCOUNTSERVICE._serialized_start=3839
  _ACCOUNTSERVICE._serialized_end=8955
# @@protoc_insertion_point(module_scope)
